#
# spec file for package kail
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kail
Version:        0.17.0
Release:        1.1
Summary:        Kubernetes log viewer
License:        MIT
Group:          System/Management
URL:            https://github.com/boz/kail
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.20
ExcludeArch:    s390
ExcludeArch:    %{ix86}

%description
Kubernetes tail: streams logs from all containers of all matched pods.
Match pods by service, replicaset, deployment, and others. Adjusts to a
changing cluster - pods are added and removed from logging as they fall
in or out of the selection.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X main.version=%{version} -X main.commit=v%{version}" \
   -o bin/%{name} ./cmd/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

%files
%license LICENSE.txt
%doc README.md
%{_bindir}/%{name}

%changelog
* Wed Nov  1 2023 kastl@b1-systems.de
- Update to version 0.17.0:
  * Update ci.yml
  * Bump github.com/rs/zerolog from 1.30.0 to 1.31.0
  * chore: use bytes.Equal(canaryLog, log) instead
  * add windows support, compile successful, make test also passed,
    replace travis-badge to GitHub actions badge
  * Fix duration in README.md tabe
  * Bump k8s.io/client-go from 0.28.1 to 0.28.3
  * Bump k8s.io/client-go from 0.27.4 to 0.28.1
  * Bump k8s.io/client-go from 0.27.3 to 0.27.4
  * Bump github.com/rs/zerolog from 1.29.1 to 1.30.0
  * Bump github.com/boz/go-lifecycle from 0.1.0 to 0.1.1
  * Bump github.com/sirupsen/logrus from 1.9.0 to 1.9.3
  * drop "with:" for removed instructions
  * Bump k8s.io/client-go from 0.27.1 to 0.27.3
  * Bump github.com/stretchr/testify from 1.8.2 to 1.8.4
  * Fix for Dockerfile smell DL3007
  * bump dependencies and golang version
  * doc: fix minikube url
  * Bump k8s.io/client-go from 0.26.2 to 0.26.3
  * Bump github.com/fatih/color from 1.14.1 to 1.15.0
  * Bump k8s.io/client-go from 0.26.1 to 0.26.2
  * Bump k8s.io/api from 0.26.1 to 0.26.2
  * Bump github.com/stretchr/testify from 1.8.1 to 1.8.2
  * Bump github.com/fatih/color from 1.14.0 to 1.14.1
  * Bump github.com/rs/zerolog from 1.28.0 to 1.29.0
  * Bump k8s.io/client-go from 0.26.0 to 0.26.1
  * Bump github.com/fatih/color from 1.13.0 to 1.14.0
  * Bump k8s.io/apimachinery from 0.26.0 to 0.26.1
  * docker build added to goreleaser
  * Bump github.com/rs/zerolog from 1.15.0 to 1.28.0
  * reverted gorelease snapshot build in test as build is taking
    longer
* Fri Jan  6 2023 kastl@b1-systems.de
- Update to version 0.16.1:
  * added separate homebrew tap token, skip homebrew publish till #84 fix
* Fri Jan  6 2023 kastl@b1-systems.de
- Update to version 0.16.0:
  * update krew index manifest update added to ci
  * add output flag details to flags table
  * removed deprecated godownloader setup
  * Add json and zerolog writers
  * use json encoder, add "pretty" mode
  * add output mode flag
  * Bump k8s.io/client-go from 0.25.4 to 0.26.0
* Fri Jan  6 2023 kastl@b1-systems.de
- add _service file
- BuildRequire go1.18
- Update to version 0.15.1:
  * added github workflow for CI, added krew, updated homebrew  (#83)
  * Bump k8s.io/client-go from 0.24.3 to 0.25.4
  * fix: update goreleaser yaml
  * Bump github.com/stretchr/testify from 1.8.0 to 1.8.1
  * chore: flip to upstream koz/kcache
  * Switch to GitHub Actions
  * Add dependabot
* Wed Mar  4 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.15.0
  - Use kcache 0.4
- Refresh vendor.tar.xz
* Tue Feb 18 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.14.2
  - Capture logs from terminated containers
- Update vendor.tar.gz
* Wed Jan 22 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.13.0
  - Add job filter
- Update vendor.tar.gz
* Tue Oct 29 2019 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.12.0
  - Handle the case when listing namespaces is forbidden (#42)
- Update vendor.tar.gz
* Mon Aug 12 2019 kukuk@suse.de
- Update to version 0.11.0
  - Write to /dev/stderr in a cross-platform way by default (#41)
* Fri Jul 26 2019 Thorsten Kukuk <kukuk@suse.com>
- Initial version
